@@ -28,6 +28,8 @@ int main(int argc, char *argv[])
     QApplication a(argc, argv);
 
     QString locale = QLocale::system().name();
+    QStringList tmp = locale.split("_");
+    locale = tmp.first();
     QString localedir = "/opt/usr/share/qcpufreq";
     QTranslator translator;
     translator.load( locale, localedir );
